@@ -1,6 +1,6 @@
 /* ncdu - NCurses Disk Usage
 
-  Copyright (c) 2007-2021 Yoran Heling
+  Copyright (c) 2007-2022 Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -70,7 +70,7 @@ struct dir {
   struct dir *parent, *next, *prev, *sub, *hlnk;
   int items;
   unsigned short flags;
-  char name[];
+  char name[FLEXIBLE_ARRAY_MEMBER];
 };
 
 /* A note on the ino and dev fields above: ino is usually represented as ino_t,
