@@ -1,6 +1,6 @@
 /* ncdu - NCurses Disk Usage
 
-  Copyright (c) 2007-2021 Yoran Heling
+  Copyright (c) 2007-2022 Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -147,6 +147,8 @@ static void argv_parse(int argc, char **argv) {
     {0,0,NULL}
   };
 
+  uic_theme = getenv("NO_COLOR") ? 0 : 2;
+
   dir_ui = -1;
   si = 0;
 
@@ -177,7 +179,7 @@ static void argv_parse(int argc, char **argv) {
       printf("  --exclude-firmlinks        Exclude firmlinks on macOS\n");
 #endif
       printf("  --confirm-quit             Confirm quitting ncdu\n");
-      printf("  --color SCHEME             Set color scheme (off/dark)\n");
+      printf("  --color SCHEME             Set color scheme (off/dark/dark-bg)\n");
       exit(0);
     case 'q': update_delay = 2000; break;
     case 'v':
@@ -229,6 +231,7 @@ static void argv_parse(int argc, char **argv) {
     case 'c':
       if(strcmp(val, "off") == 0)  { uic_theme = 0; }
       else if(strcmp(val, "dark") == 0) { uic_theme = 1; }
+      else if(strcmp(val, "dark-bg") == 0) { uic_theme = 2; }
       else {
         fprintf(stderr, "Unknown --color option: %s\n", val);
         exit(1);
