@@ -1,6 +1,6 @@
 /* ncdu - NCurses Disk Usage
 
-  Copyright (c) 2007-2021 Yoran Heling
+  Copyright (c) 2007-2022 Yoran Heling
   Shell support: Copyright (c) 2014 Thomas Jarosch
 
   Permission is hereby granted, free of charge, to any person obtaining
@@ -36,11 +36,12 @@
 
 static void set_level(void) {
   static int done = 0;
+  const char *lvl;
   char nlvl[2];
   if(done)
     return;
-  const char *lvl = getenv("NCDU_LEVEL");
-  // too lazy to count beyond 9
+  lvl = getenv("NCDU_LEVEL");
+  /* too lazy to count beyond 9 */
   if(lvl && *lvl >= '1' && *lvl < '9' && lvl[1] == 0) {
     nlvl[0] = 1 + *lvl;
     nlvl[1] = 0;
