@@ -1,6 +1,6 @@
 /* ncdu - NCurses Disk Usage
 
-  Copyright (c) 2007-2021 Yoran Heling
+  Copyright (c) 2007-2022 Yoran Heling
 
   Permission is hereby granted, free of charge, to any person obtaining
   a copy of this software and associated documentation files (the
@@ -147,10 +147,13 @@ char *fmtmode(unsigned short mode) {
 
 
 void read_locale() {
+#ifdef HAVE_LOCALE_H
+  char *locale_thou_sep;
+#endif
   thou_sep = '.';
 #ifdef HAVE_LOCALE_H
   setlocale(LC_ALL, "");
-  char *locale_thou_sep = localeconv()->thousands_sep;
+  locale_thou_sep = localeconv()->thousands_sep;
   if(locale_thou_sep && 1 == strlen(locale_thou_sep))
     thou_sep = locale_thou_sep[0];
 #endif
@@ -250,10 +253,16 @@ static const struct {
   short fg, bg;
   int attr;
 } color_defs[] = {
-#define C(name, off_fg, off_bg, off_a, dark_fg, dark_bg, dark_a) \
-  {off_fg,  off_bg,  off_a}, \
-  {dark_fg, dark_bg, dark_a},
+#define COLOR__ -1
+#define B A_BOLD
+#define R A_REVERSE
+#define C(name, off_fg, off_bg, off_a, dark_fg, dark_bg, dark_a, darkbg_fg, darkbg_bg, darkbg_a) \
+  {COLOR_##off_fg,    COLOR_##off_bg,    off_a}, \
+  {COLOR_##dark_fg,   COLOR_##dark_bg,   dark_a}, \
+  {COLOR_##darkbg_fg, COLOR_##darkbg_bg, darkbg_a},
   UI_COLORS
+#undef B
+#undef R
 #undef C
   {0,0,0}
 };
@@ -264,7 +273,7 @@ void uic_init() {
   start_color();
   use_default_colors();
   for(i=0; i<sizeof(colors)/sizeof(*colors)-1; i++) {
-    j = i*2 + uic_theme;
+    j = i*3 + uic_theme;
     init_pair(i+1, color_defs[j].fg, color_defs[j].bg);
     colors[i] = color_defs[j].attr | COLOR_PAIR(i+1);
   }
